=== modified file 'NEWS'
--- NEWS	2010-10-08 09:46:20 +0000
+++ NEWS	2011-02-01 17:18:37 +0000
@@ -2,8 +2,18 @@
 
  BUG FIXES
 
+  * make sure that gdiff opened from gannotate knows its parent
+    (gannotate, that is, and does not exit when it (gdiff) is closed.
+
+  * Clarify 'visualise' help about the multiple branches feature
+    and the --revision parameter. (Vincent Ladeuil, #556347)
+
   * Mark as compatible with bzr 2.3. (Jelmer Vernooij)
 
+  * Fix appindicator icon category. (Michael Terry, #685634)
+
+  * Mark as compatible with Bazaar 2.4. (Jelmer Vernooij)
+
 0.99.1	2010-08-26
 
  BUG FIXES

=== modified file '__init__.py'
--- __init__.py	2010-08-13 20:50:53 +0000
+++ __init__.py	2011-01-31 10:19:52 +0000
@@ -15,22 +15,22 @@
 """Graphical support for Bazaar using GTK.
 
 This plugin includes:
-gannotate         GTK+ annotate. 
-gbranch           GTK+ branching. 
-gcheckout         GTK+ checkout. 
+gannotate         GTK+ annotate.
+gbranch           GTK+ branching.
+gcheckout         GTK+ checkout.
 gcommit           GTK+ commit dialog.
-gconflicts        GTK+ conflicts. 
-gdiff             Show differences in working tree in a GTK+ Window. 
+gconflicts        GTK+ conflicts.
+gdiff             Show differences in working tree in a GTK+ Window.
 ginit             Initialise a new branch.
 gloom             GTK+ loom browse dialog
 gmerge            GTK+ merge dialog
-gmissing          GTK+ missing revisions dialog. 
-gpreferences      GTK+ preferences dialog. 
+gmissing          GTK+ missing revisions dialog.
+gpreferences      GTK+ preferences dialog.
 gpush             GTK+ push.
 gsend             GTK+ send merge directive.
 gstatus           GTK+ status dialog.
 gtags             Manage branch tags.
-visualise         Graphically visualise this branch. 
+visualise         Graphically visualise this branch.
 """
 
 import os
@@ -109,17 +109,6 @@
     return data_path(os.path.join('icons', *args))
 
 
-def open_display():
-    pygtk = import_pygtk()
-    try:
-        import gtk
-    except RuntimeError, e:
-        if str(e) == "could not open display":
-            raise NoDisplayError
-    set_ui_factory()
-    return gtk
-
-
 commands = {
     "gannotate": ["gblame", "gpraise"],
     "gbranch": [],
@@ -132,7 +121,6 @@
     "gmissing": [],
     "gpreferences": [],
     "gpush": [],
-    "gselftest": [],
     "gsend": [],
     "gstatus": ["gst"],
     "gtags": [],
@@ -158,13 +146,6 @@
                                        save_commit_messages,
                                        "Saving commit messages for gcommit")
 
-class NoDisplayError(errors.BzrCommandError):
-    """gtk could not find a proper display"""
-
-    def __str__(self):
-        return "No DISPLAY. Unable to run GTK+ application."
-
-
 credential_store_registry = getattr(config, "credential_store_registry", None)
 if credential_store_registry is not None:
     try:

=== modified file 'about.py'
--- about.py	2008-07-18 20:12:54 +0000
+++ about.py	2010-12-17 22:48:28 +0000
@@ -23,9 +23,6 @@
 import bzrlib
 import gtk
 import os
-from bzrlib.branch import Branch
-from bzrlib.errors import NotBranchError, NoRepositoryPresent
-from bzrlib.trace import mutter
 
 from bzrlib.plugins.gtk import data_path, icon_path
 

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2010-05-27 02:28:54 +0000
+++ annotate/gannotate.py	2011-02-01 17:18:37 +0000
@@ -49,9 +49,9 @@
         self.all = all
         self.plain = plain
         self._branch = branch
-        
+
         Window.__init__(self, parent)
-        
+
         self.set_icon(self.render_icon(gtk.STOCK_FIND, gtk.ICON_SIZE_BUTTON))
         self.annotate_colormap = AnnotateColorSaturation()
 
@@ -68,15 +68,15 @@
         self.revisionview.set_file_id(file_id)
         self.revision_id = getattr(tree, 'get_revision_id', 
                                    lambda: CURRENT_REVISION)()
-        
+
         # [revision id, line number, author, revno, highlight color, line]
         self.annomodel = gtk.ListStore(gobject.TYPE_STRING,
-                                       gobject.TYPE_STRING,
+                                       gobject.TYPE_INT,
                                        gobject.TYPE_STRING,
                                        gobject.TYPE_STRING,
                                        gobject.TYPE_STRING,
                                        gobject.TYPE_STRING)
-        
+
         last_seen = None
         try:
             branch.lock_read()
@@ -86,7 +86,7 @@
             for revision_id, revno in revno_map.iteritems():
                 self.dotted[revision_id] = '.'.join(str(num) for num in revno)
             for line_no, (revision, revno, line)\
-                    in enumerate(self._annotate(tree, file_id)):
+                in enumerate(self._annotate(tree, file_id)):
                 if revision.revision_id == last_seen and not self.all:
                     revno = author = ""
                 else:
@@ -102,7 +102,7 @@
                                        revno,
                                        None,
                                        line.rstrip("\r\n")
-                                      ])
+                                       ])
                 self.annotations.append(revision)
 
             if not self.plain:
@@ -125,7 +125,7 @@
             # bar?
             print("gannotate: Line number %d does't exist. Defaulting to "
                   "line 1." % lineno)
-	    return
+            return
         else:
             row = lineno - 1
 
@@ -218,7 +218,7 @@
         hbox.pack_start(self.goto_button, expand=False, fill=True)
         hbox.show()
         vbox.pack_start(hbox, expand=False, fill=True)
-        
+
         self.pane = pane = gtk.VPaned()
         pane.add1(swbox)
         pane.add2(self.revisionview)
@@ -260,7 +260,7 @@
             else:
                 tree2 = repository.revision_tree(NULL_REVISION)
         from bzrlib.plugins.gtk.diff import DiffWindow
-        window = DiffWindow()
+        window = DiffWindow(self)
         window.set_diff("Diff for line %d" % (row+1), tree1, tree2)
         window.set_file(tree1.id2path(self.file_id))
         window.show()
@@ -532,18 +532,22 @@
 
     def _match(self, model, iterator, column):
         matching_case = self._match_case.get_active()
-        string, = model.get(iterator, column)
+        cell_value, = model.get(iterator, column)
         key = self._entry.get_text()
-        if self._regexp.get_active():
+        if column == LINE_NUM_COL:
+            # FIXME: For goto-line there are faster algorithms than searching 
+            # every line til we find the right one! -- mbp 2011-01-27
+            return key.strip() == str(cell_value)
+        elif self._regexp.get_active():
             if matching_case:
-                match = re.compile(key).search(string, 1)
+                match = re.compile(key).search(cell_value, 1)
             else:
-                match = re.compile(key, re.I).search(string, 1)
+                match = re.compile(key, re.I).search(cell_value, 1)
         else:
             if not matching_case:
-                string = string.lower()
+                cell_value = cell_value.lower()
                 key = key.lower()
-            match = string.find(key) != -1
+            match = cell_value.find(key) != -1
 
         return match
 
@@ -583,4 +587,4 @@
                 path = model.get_path(row)
                 self._view.set_cursor(path)
                 self._view.scroll_to_cell(path, use_align=True)
-                break
+                break
\ No newline at end of file

=== modified file 'bzr-notify'
--- bzr-notify	2010-10-20 00:54:47 +0000
+++ bzr-notify	2011-02-15 00:15:40 +0000
@@ -34,7 +34,7 @@
     show_icon = lambda: icon.set_visible(True)
 else:
     indicator = appindicator.Indicator ("bzr-gtk-notify",
-        "bzr-panel", appindicator.CATEGORY_APPLICATION_STATUS)
+        "bzr-panel", appindicator.CATEGORY_OTHER)
     indicator.set_status (appindicator.STATUS_PASSIVE)
     indicator.set_attention_icon("bzr-panel")
     indicator.set_menu(menu)

=== modified file 'commands.py'
--- commands.py	2010-06-17 20:25:04 +0000
+++ commands.py	2011-01-31 10:19:52 +0000
@@ -16,7 +16,7 @@
 
 from bzrlib import (
     branch,
-    builtins,
+    errors,
     workingtree,
     )
 from bzrlib.commands import (
@@ -33,11 +33,30 @@
 
 from bzrlib.plugins.gtk import (
     _i18n,
-    open_display,
     import_pygtk,
     set_ui_factory,
     )
 
+
+class NoDisplayError(errors.BzrCommandError):
+    """gtk could not find a proper display"""
+
+    def __str__(self):
+        return "No DISPLAY. Unable to run GTK+ application."
+
+
+def open_display():
+    pygtk = import_pygtk()
+    try:
+        import gtk
+    except RuntimeError, e:
+        if str(e) == "could not open display":
+            raise NoDisplayError
+    set_ui_factory()
+    return gtk
+
+
+
 class GTKCommand(Command):
     """Abstract class providing GTK specific run commands."""
 
@@ -162,13 +181,15 @@
 
 
 class cmd_visualise(Command):
-    """Graphically visualise this branch.
-
-    Opens a graphical window to allow you to see the history of the branch
-    and relationships between revisions in a visual manner,
-
-    The default starting point is latest revision on the branch, you can
-    specify a starting point with -r revision.
+    """Graphically visualise one or several branches.
+
+    Opens a graphical window to allow you to see branches history and
+    relationships between revisions in a visual manner,
+
+    If no revision is specified, the branch last revision is taken as a
+    starting point. When a revision is specified, the presented graph starts
+    with it (as a side effect, when a shared repository is used, any revision
+    can be used even if it's not part of the branch history).
     """
     takes_options = [
         "revision",
@@ -460,34 +481,3 @@
         window = TagsWindow(br)
         window.show()
         gtk.main()
-
-
-class cmd_gselftest(GTKCommand):
-    """Version of selftest that displays a notification at the end"""
-
-    takes_args = builtins.cmd_selftest.takes_args
-    takes_options = builtins.cmd_selftest.takes_options
-    _see_also = ['selftest']
-
-    def run(self, *args, **kwargs):
-        import cgi
-        import sys
-        default_encoding = sys.getdefaultencoding()
-        # prevent gtk from blowing up later
-        gtk = import_pygtk()
-        # prevent gtk from messing with default encoding
-        import pynotify
-        if sys.getdefaultencoding() != default_encoding:
-            reload(sys)
-            sys.setdefaultencoding(default_encoding)
-        result = builtins.cmd_selftest().run(*args, **kwargs)
-        if result == 0:
-            summary = 'Success'
-            body = 'Selftest succeeded in "%s"' % os.getcwd()
-        if result == 1:
-            summary = 'Failure'
-            body = 'Selftest failed in "%s"' % os.getcwd()
-        pynotify.init("bzr gselftest")
-        note = pynotify.Notification(cgi.escape(summary), cgi.escape(body))
-        note.set_timeout(pynotify.EXPIRES_NEVER)
-        note.show()

=== modified file 'info.py'
--- info.py	2010-08-27 11:59:38 +0000
+++ info.py	2011-01-17 03:38:49 +0000
@@ -25,14 +25,7 @@
 #FIXME: fill this in automatically somehow
 bzr_commands = []
 
-bzr_compatible_versions = [(1, 6, 0), (1, 7, 0), (1, 8, 0), (1, 9, 0),
-                           (1, 10, 0), (1, 11, 0), (1, 12, 0), (1, 13, 0),
-                           (1, 15, 0),
-                           (1, 17, 0),
-                           (2, 1, 0),
-                           (2, 2, 0),
-                           (2, 3, 0),
-                           ]
+bzr_compatible_versions = [(2, 1, 0), (2, 2, 0), (2, 3, 0), (2, 4, 0)]
 
 bzr_minimum_version = bzr_compatible_versions[0]
 

=== modified file 'revisionview.py'
--- revisionview.py	2009-06-10 18:07:35 +0000
+++ revisionview.py	2009-12-09 13:27:53 +0000
@@ -51,13 +51,15 @@
             webbrowser._tryorder.insert(0, '%s "%%s"' % cmd)
     webbrowser.open(uri)
 
-gtk.link_button_set_uri_hook(_open_link)
+if getattr(gtk, 'link_button_set_uri_hook', None) is not None:
+    # Not available before PyGtk-2.10
+    gtk.link_button_set_uri_hook(_open_link)
 
 class BugsTab(gtk.VBox):
 
     def __init__(self):
         super(BugsTab, self).__init__(False, 6)
-    
+
         table = gtk.Table(rows=2, columns=2)
 
         table.set_row_spacings(6)

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2009-05-25 15:57:23 +0000
+++ viz/branchwin.py	2009-12-09 17:38:48 +0000
@@ -1,11 +1,10 @@
-# -*- coding: UTF-8 -*-
 """Branch window.
 
 This module contains the code to manage the branch information window,
 which contains both the revision graph and details panes.
 """
 
-__copyright__ = "Copyright © 2005 Canonical Ltd."
+__copyright__ = "Copyright (c) 2005 Canonical Ltd."
 __author__    = "Scott James Remnant <scott@ubuntu.com>"
 
 
@@ -80,7 +79,9 @@
         self.accel_group = gtk.AccelGroup()
         self.add_accel_group(self.accel_group)
 
-        gtk.Action.set_tool_item_type(gtk.MenuToolButton)
+        if getattr(gtk.Action, 'set_tool_item_type', None) is not None:
+            # Not available before PyGtk-2.10
+            gtk.Action.set_tool_item_type(gtk.MenuToolButton)
 
         self.prev_rev_action = gtk.Action("prev-rev", "_Previous Revision", "Go to the previous revision", gtk.STOCK_GO_DOWN)
         self.prev_rev_action.set_accel_path("<viz>/Go/Previous Revision")
@@ -413,7 +414,8 @@
                 self.prev_rev_action.set_sensitive(False)
                 prev_menu.hide()
 
-            self.prev_button.set_menu(prev_menu)
+            if getattr(self.prev_button, 'set_menu', None) is not None:
+		self.prev_button.set_menu(prev_menu)
 
             next_menu = gtk.Menu()
             if len(children) > 0:
@@ -433,7 +435,8 @@
                 self.next_rev_action.set_sensitive(False)
                 next_menu.hide()
 
-            self.next_button.set_menu(next_menu)
+            if getattr(self.next_button, 'set_menu', None) is not None:
+		self.next_button.set_menu(next_menu)
 
             self.revisionview.set_revision(revision)
             self.revisionview.set_children(children)

